@@ -1,23 +1,26 @@
 # $File: //member/autrijus/Module-Install-RTx/lib/Module/Install/RTx.pm $ $Author: autrijus $
-# $Revision: #12 $ $Change: 9841 $ $DateTime: 2004/02/01 20:07:17 $ vim: expandtab shiftwidth=4
+# $Revision: #14 $ $Change: 10586 $ $DateTime: 2004/05/10 16:39:52 $ vim: expandtab shiftwidth=4
 
 package Module::Install::RTx;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$Module::Install::RTx::VERSION = '0.05';
+$Module::Install::RTx::VERSION = '0.06';
 
 use strict;
 use FindBin;
+use File::Glob;
 use File::Basename;
 
 sub RTx {
     my ($self, $name) = @_;
+    my $RTx = 'RTx';
+    $RTx = $1 if $name =~ s/^(\w+)-//;
 
-    $self->name("RTx-$name")
+    $self->name("$RTx-$name")
         unless $self->name;
     $self->abstract("RT $name Extension")
         unless $self->abstract;
-    $self->version_from (-e "$name.pm" ? "$name.pm" : "lib/RTx/$name.pm")
+    $self->version_from (-e "$name.pm" ? "$name.pm" : "lib/$RTx/$name.pm")
         unless $self->version;
 
     my @prefixes = (qw(/opt /usr/local /home /usr /sw ));
@@ -35,12 +38,17 @@ sub RTx {
             map {( "$_/rt3/lib", "$_/lib/rt3", "$_/lib" )} grep $_, @prefixes
         );
         until ( eval { require RT; $RT::LocalPath } ) {
-            warn "Cannot find the location of RT.pm that defines \$RT::LocalPath.\n";
-            $_ = prompt("Path to your RT.pm:") or exit;
+            warn "Cannot find the location of RT.pm that defines \$RT::LocalPath. ($@)\n";
+            $_ = $self->prompt("Path to your RT.pm:") or exit;
             push @INC, $_, "$_/rt3/lib", "$_/lib/rt3";
         }
+
+        package RT;
+        require $RT::SITE_CONFIG_FILE;
+        require $RT::CORE_CONFIG_FILE;
     }
 
+    my $lib_path = dirname($INC{'RT.pm'});
     print "Using RT configurations from $INC{'RT.pm'}:\n";
 
     $RT::LocalVarPath	||= $RT::VarPath;
@@ -67,6 +75,14 @@ sub RTx {
     $path{lib} = "$RT::LocalPath/lib" unless %subdirs and !$subdirs{'lib'};
     print "./$_\t=> $path{$_}\n" for sort keys %path;
 
+    if (my @dirs = map { (-D => $_) } grep $path{$_}, qw(bin html sbin)) {
+        my @po = map { (-o => $_) } grep -f, File::Glob::bsd_glob("po/*.po");
+        $self->postamble(<< ".") if @po;
+lexicons ::
+\t\$(NOECHO) \$(PERL) -MLocale::Maketext::Extract::Run=xgettext -e \"xgettext(qw(@dirs @po))\"
+.
+    }
+
     my $postamble = << ".";
 install ::
 \t\$(NOECHO) \$(PERL) -MExtUtils::Install -e \"install({$args})\"
@@ -79,6 +95,27 @@ install ::
 .
     }
 
+    my %has_etc;
+    if (File::Glob::bsd_glob("$FindBin::Bin/etc/schema.*")) {
+        # got schema, load factory module
+        $has_etc{schema}++;
+        $self->load('RTxFactory');
+        $self->postamble(<< ".");
+factory ::
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" -Minc::Module::Install -e"RTxFactory(qw($RTx $name))"
+
+dropdb ::
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" -Minc::Module::Install -e"RTxFactory(qw($RTx $name drop))"
+
+.
+    }
+    if (File::Glob::bsd_glob("$FindBin::Bin/etc/acl.*")) {
+        $has_etc{acl}++;
+    }
+    if (-e 'etc/initialdata') {
+        $has_etc{initialdata}++;
+    }
+
     $self->postamble("$postamble\n");
     if (%subdirs and !$subdirs{'lib'}) {
         $self->makemaker_args(
@@ -89,16 +126,35 @@ install ::
         $self->makemaker_args( INSTALLSITELIB => "$RT::LocalPath/lib" );
     }
 
-    if (-e 'etc/initialdata') {
-        print "For first-time installation, type 'make initialize-database'.\n";
-        my $lib_path = dirname($INC{'RT.pm'});
-        $self->postamble(<< ".");
-initialize-database ::
-\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" "$RT::BasePath/sbin/rt-setup-database" --action=insert --datafile=etc/initialdata
+    if (%has_etc) {
+        RTxInit();
+        $RT::SbinPath = $RT::LocalPath;
+        $RT::SbinPath =~ s/local$/sbin/;
+
+        print "For first-time installation, type 'make initdb'.\n";
+        my $initdb = "initdb ::\n";
+        $initdb .= <<"." if $has_etc{schema};
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" "$RT::SbinPath/rt-setup-database" --action=schema --datadir ./etc/ --prompt-for-dba-password --dba $RT::DatabaseUser
 .
+        $initdb .= <<"." if $has_etc{acl};
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" "$RT::SbinPath/rt-setup-database" --action=acl --datadir ./etc/ --prompt-for-dba-password --dba $RT::DatabaseUser
+.
+        $initdb .= <<"." if $has_etc{initialdata};
+\t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" "$RT::SbinPath/rt-setup-database" --action=insert --datafile=etc/initialdata --dba $RT::DatabaseUser
+.
+        $self->postamble("$initdb\n");
     }
 }
 
+sub RTxInit {
+    unshift @INC, substr(delete($INC{'RT.pm'}), 0, -5) if $INC{'RT.pm'};
+    require RT;
+    RT::LoadConfig();
+    RT::ConnectToDatabase();
+
+    die "Cannot load RT" unless $RT::Handle and $RT::DatabaseType;
+}
+
 1;
 
 __END__
